# FailureReasonDetails

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**failure_reason** | [**FailureReason**](FailureReason.md) |  | 
**site_reference_numbers** | **list[str]** | Required if work has a reinstatement | [optional] 
**details** | **str** | Max length 500 characters | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

